;=================================================================
;      The Coevolution of the Firm and the Product Space
;                     by: Cesar Garcia-Diaz
;                        This version:
;                        Octubre 30, 2018
;                     18:17 Hrs (GMT - 5)
;=================================================================

;=================================================================
;      VARIABLE / PARAMETER DEFINITIONS & SIMULATION SETUP
;=================================================================

extensions [matrix]
breed [firms firm]
breed [variants variant]

patches-own [patch-id] ;patch id

firms-own [firm-type ;takes "alpha" if the firm is alpha-type (i.e. endowed with scale advantages); "beta" if not endowed with scale advantages
           quantity-per-variant ;list of production quantities
           niche-positions ;list that contains the variants' id that the firm serves
           unit-cost-per-variant ;list of unit production cost
           profits-per-variant ;list of firm profits per variant in last transaction
           overall-cumulative-profits ;cumulative profits over all variants (which includes niche-width costs + cost of creating new variants)
           last-transaction-cost ;total costs on last transaction
           last-transaction-profit ;records last transaction profit
           inactive-patch-candidates ;registers (inactive) patch candidates for next expansion
           active-patch-candidates ;registers (active) patch candidates for next expansion

]

variants-own [price ;variant price
              alpha-firm-list ;list of alpha-type id's on the variant
              beta-firm-list ;list of beta-type id's on the variant
              n-alpha ;number of alpha-type firms
              n-beta ;number of beta-type firms
              Q-alpha ;quantity produced by alpha-type firms
              Q-beta ;quantity produced by beta-type firms
              variant-number-of-firms ;number of firms offering product at the variant
              baseline-unit-cost ;unit production cost of this variant when there are no scale economies (beta-type firms). It is drawn from uniform distribution (=cbeta)
              scale-factor ;affects computation of unit production cost in the presence of scale economies (alpha-type firms), calpha = cbeta - e*q, e  = scale-factor
              ;in order to reflect a noticeable difference in scale economies between the two firm types, we assume that scale-factor ranges between [x, 0.5), x > 0
]

globals [variants-to-create ;this list registers location of new variants
         price-equation-intercept ;corresponds to the value of "a" in the equation P = a - b*Q. Same for all variants; a = market-size
         price-equation-slope ;corresponds to the value of "b" in the equation P = a - b*Q. Same for all variants; b = a / (total market per variant) = #variants
         variants-opened-up-by-alpha ;tracks the variants opened up by alpha-type firms (notice that many firms (and from both types) can simultaneously contribute to opening up variants)
         variants-opened-up-by-beta ;tracks the variants opened up by beta-type firms (notice that many firms (and from both types) can simultaneously contribute to opening up variants)

]

to setup
   ;random-seed 0
   random-seed timer * random-float 1 * 1e5
   clear-all ;; clear-all
   if (parameter-value-combination != -1) [lh-design-points] ;when equal to -1, parameter valuesare selected from sliders from the interface
   set variants-opened-up-by-alpha 0
   set variants-opened-up-by-beta 0

   set-default-shape variants "dot"
   set-default-shape firms "dot"
   ;set-patch-size 35 ;this has been already set at the Model Settings panel
   ;resize-world 0 10 0 10 ;this has been already set at the Model Settings panel; pxcor, pycor < 99

   ask patches [set pcolor white set patch-id pxcor * 100 + pycor]

   ask patch initial-x-position initial-y-position [
                    sprout-variants 1 ;initial condition sets a single variant at the center
                    sprout-firms total-number-of-firms ;firms are created
                    ask firms [
                        let type-var random-float 1
                        ifelse type-var > 0.5 [set firm-type "alpha"] [set firm-type "beta"]
                        set niche-positions (list patch-id) ;notice this a list
                        set quantity-per-variant [0] ;initial value / empty list
                        set unit-cost-per-variant [0] ;initial value / empty list
                        set profits-per-variant [0] ;initial value / empty list
                        set overall-cumulative-profits 0 ;initial value
                        set last-transaction-cost 0 ;initial value
                        set last-transaction-profit 0 ;initial value
                        set inactive-patch-candidates [] ;initial value is an empty list
                        set active-patch-candidates [] ;initial value is an empty list
                        set color white
                    ]
   ]

   ;Initialization procedure: There is only one variant at this point
   set price-equation-intercept market-size ;initialization
   set price-equation-slope count variants ;initialization

   ask variants [
       set color red
       set price 0
       set alpha-firm-list [] ;initialization
       set beta-firm-list [] ;initialization
       set n-alpha 0 ;initialization
       set n-beta 0 ;initialization
       set Q-alpha 0 ;initialization
       set Q-beta 0 ;initialization
       set variant-number-of-firms 0 ;initialization
       set scale-factor 0.45 + random-float 0.05 ;scale factor has to strictly be less than 0.5 (e < 1/2)
       ;a lower bound for baseline-unit-cost is cbeta > e * market-size; also, cbeta should be lower than the price-intercept (a - cbeta > 0)
       set baseline-unit-cost (scale-factor * market-size) + random-float (price-equation-intercept - scale-factor * market-size)

  ]

   reset-ticks
end

to lh-design-points
   ;Latin hypercube experimental design (Matlab result)
   ;see additional malab code lhs_design.m (design chosen among 10000 design with the lowest average absolute pairwise correlation = 0.002)
   ;sample size = 20 design points

   let d-points-normalized matrix:from-row-list [;generated with the Matlab code lhs_design.m
    [0.675	0.025	0.775]
    [0.575	0.625	0.525]
    [0.025	0.075	0.375]
    [0.075	0.275	0.925]
    [0.175	0.825	0.675]
    [0.475	0.775	0.725]
    [0.275	0.525	0.325]
    [0.125	0.425	0.825]
    [0.625	0.125	0.275]
    [0.975	0.225	0.975]
    [0.825	0.925	0.875]
    [0.925	0.325	0.175]
    [0.425	0.975	0.225]
    [0.375	0.875	0.425]
    [0.875	0.375	0.475]
    [0.725	0.675	0.625]
    [0.775	0.475	0.125]
    [0.225	0.175	0.075]
    [0.525	0.725	0.025]
    [0.325	0.575	0.575]
  ]

  let d-points-adjusted matrix:from-row-list [
    ;Parameter value calculation: Each column adjusted according to max. / min. slider values:
    ;d-point-adjusted = min-value + d-point-normalized * (max-value - min-value) 		
    ;[total-number-of-firms	niche-width-cost	k-cost]

    [17	525	21625]
    [16	1125	17875]
    [10	575	15625]
    [11	775	23875]
    [12	1325	20125]
    [15	1275	20875]
    [13	1025	14875]
    [11	925	22375]
    [16	625	14125]
    [20	725	24625]
    [18	1425	23125]
    [19	825	12625]
    [14	1475	13375]
    [14	1375	16375]
    [19	875	17125]
    [17	1175	19375]
    [18	975	11875]
    [12	675	11125]
    [15	1225	10375]
    [13	1075	18625]


  ]
  set total-number-of-firms matrix:get d-points-adjusted parameter-value-combination 0 ;range = [10, 20]
  set niche-width-cost matrix:get d-points-adjusted parameter-value-combination 1; range = [500, 1500]
  set k-cost matrix:get d-points-adjusted parameter-value-combination 2; range = [10000, 25000]

end

;=================================================================
;                       MODEL DYNAMICS
;=================================================================

to go
   if ticks >= 200 [stop]
   set-cournot-competition
   set-firm-expansion
   update-variant-population
   update-variant-size
   tick
end

to set-cournot-competition
   set price-equation-slope count variants ;we update price equation slope given the newly created variants
   ask firms [set last-transaction-cost 0] ;we reset the last transaction cost

   ask variants [
       set color blue
       let alpha-firm-list-temp [] ;contains the id's of alpha-type firms on this variant
       let beta-firm-list-temp []  ;;contains the id's of beta-type firms on this variant
       let this-variant [patch-id] of patch-here
       let this-variant-id who

       ask firms [
           let counter 0
           while [counter < length niche-positions] [

             if (item counter niche-positions = this-variant) [
                set counter length niche-positions
                ifelse (firm-type = "alpha") [
                      set alpha-firm-list-temp lput who alpha-firm-list-temp
                    ]; first ifelse block
                    [
                      set beta-firm-list-temp lput who beta-firm-list-temp
                    ];second ifelse block
             ];end if block

             set counter counter + 1
           ];end while block

       ];end ask block

       set n-alpha length alpha-firm-list-temp
       set n-beta length beta-firm-list-temp
       set alpha-firm-list alpha-firm-list-temp
       set beta-firm-list beta-firm-list-temp

       set Q-alpha n-alpha * (price-equation-intercept - baseline-unit-cost)/(price-equation-slope * (n-alpha + n-beta + 1) - 2 * scale-factor * (n-beta + 1))
       ;Qalpha=nalpha*(a-cbeta)/(b*(nalpha+nbeta+1)-2e(nbeta+1))
       set Q-beta (n-beta * ((price-equation-slope - 2 * scale-factor) / price-equation-slope)) * (price-equation-intercept - baseline-unit-cost)/(price-equation-slope * (n-alpha + n-beta + 1) - 2 * scale-factor * (n-beta + 1))
       ;Qbeta=(nbeta*((b-2e)/b)*(a-cbeta)/(b*(nalpha+nbeta+1)-2e(nbeta+1))
       set variant-number-of-firms n-alpha + n-beta
       set price price-equation-intercept - price-equation-slope * (Q-alpha + Q-beta)

    foreach alpha-firm-list [ [x] ->
             ask firm x [
                 let location position this-variant niche-positions ;finds the position of this variant in firm´s niche
                 set quantity-per-variant replace-item location quantity-per-variant (([Q-alpha] of variant this-variant-id) / ([n-alpha] of variant this-variant-id))
                 set unit-cost-per-variant replace-item location unit-cost-per-variant (([baseline-unit-cost] of variant this-variant-id) - ([scale-factor] of variant this-variant-id) * (item location quantity-per-variant))
                 let price-this-variant [price] of variant this-variant-id
                 let unit-cost-this-variant item location unit-cost-per-variant
                 set profits-per-variant replace-item location profits-per-variant ((price-this-variant - unit-cost-this-variant) * (item location quantity-per-variant))
                 set last-transaction-cost last-transaction-cost + unit-cost-this-variant * (item location quantity-per-variant)
             ]
       ]

    foreach beta-firm-list [ [x] ->
             ask firm x [
                 let location position this-variant niche-positions ;finds the position of this variant in firm´s niche
                 set quantity-per-variant replace-item location quantity-per-variant (([Q-beta] of variant this-variant-id) / ([n-beta] of variant this-variant-id))
                 set unit-cost-per-variant replace-item location unit-cost-per-variant ([baseline-unit-cost] of variant this-variant-id)
                 let price-this-variant [price] of variant this-variant-id
                 let unit-cost-this-variant item location unit-cost-per-variant
                 set profits-per-variant replace-item location profits-per-variant ((price-this-variant - unit-cost-this-variant) * (item location quantity-per-variant))
                 set last-transaction-cost last-transaction-cost + unit-cost-this-variant * (item location quantity-per-variant)
             ]
       ]


   ] ;end "ask variants" block

   ;Compute firm's cumulative profits and record last-transaction profit
   ask firms [
       let total-niche-cost niche-width-cost * block-distance niche-positions
       set last-transaction-profit sum profits-per-variant - total-niche-cost
       set last-transaction-cost last-transaction-cost + total-niche-cost ;we add niche costs
       set overall-cumulative-profits overall-cumulative-profits + last-transaction-profit

   ]

end

to set-firm-expansion

  ;Firms choose among four alternatives (according to highest profits)
  ;(i) To keep current niche. Firm considers keeping things as they are (default action). The last-transaction-profit is taken as a reference value
  ;(ii) To open up a new variant. Firm considers opening up a new variant (in an empty, inactive, patch). Firms pay a one-time charge for it.
  ;(iii) to expand into an existing variant. Firm considers expanding into an existing, active, variant (if any in the surroundings), already opened up by another firm
  ;(iv) to drop an existing one
  ;--------------------------------------------------------------------------------------------------------------------------------
  ;first, we obtain the "variant candidates" (both active and inactive) from those patches the surround the existing niche of the firm
  set variants-to-create [] ;this list registers location of new variants

  ask firms [
      let surrounding-inactive-patches [] ;initialization; contains id's of inactive patches (i.e., with no variants) surrounding current niche
      let surrounding-active-patches [] ;initialization; contains id's of active patches (i.e., with variants) surrounding current niche
      let niche-temp-list niche-positions ;auxiliary variable

      foreach niche-temp-list [ ?1 ->
              ask patches with [patch-id = ?1] [
                  ask neighbors4 [;Von Neumann neighborhood: a minimum affinity (either on the X or Y location) should be kept when creating a variant
                      ifelse (count variants-here = 0)
                      [set surrounding-inactive-patches lput patch-id surrounding-inactive-patches]
                      [;if there are variants here, patch is already active. To consider it as a patch candidate, we need to check that it does not belong to the firm
                       if position patch-id niche-temp-list = false [set surrounding-active-patches lput patch-id surrounding-active-patches]
                      ]
                  ]

              ] ;end block ask patches with [patch-id = ?]

      ]; end block foreach niche-temp-list

      set inactive-patch-candidates surrounding-inactive-patches ;expansion candidates that are empty
      set active-patch-candidates surrounding-active-patches ;expansion candidates already opened

      ;firms choose randomly one potential position among the inactive-patch-candidates, and one among the active-patch-candidates

      ;computation of profits -- case (ii)
      ;----------------------------------------------------------------------------------------------------------------------------
      let inactive-selected -1 ;initialization; this variable picks up one of the inactive-patch-candidates
      let inactive-related-profits -1e300 ;initialization
      if length inactive-patch-candidates > 0 [
         set inactive-selected one-of inactive-patch-candidates
         let niche-positions-old niche-positions
         set niche-positions-old lput inactive-selected niche-positions-old

         let profit-new-variant 0
         ifelse firm-type = "alpha"
             [
              let estimated-scale-factor 0.45 + random-float 0.05 ;scale factor has to strictly be less than 0.5 (e < 1/2)
              ;a lower bound for estimated-baseline-unit-cost is cbeta > e * market-size; also, cbeta should be lower than the price-intercept (a - cbeta > 0)
              let estimated-baseline-unit-cost (estimated-scale-factor * market-size) + random-float (price-equation-intercept - estimated-scale-factor * market-size)
              let scenario-ii-quantity (price-equation-intercept - estimated-baseline-unit-cost) / (2 * (price-equation-slope - estimated-scale-factor)) ;q = (a-c_beta)/(2(b-e))
              ;we compute profits = (a-b*q)*q - (c_beta - e*q) * q; note that the firm assumes the current (known) slope value.
              set profit-new-variant (price-equation-intercept - price-equation-slope * scenario-ii-quantity) * scenario-ii-quantity - (estimated-baseline-unit-cost - estimated-scale-factor * scenario-ii-quantity) * scenario-ii-quantity
              ]
             [;that is, if firm type is "beta"
              let estimated-scale-factor 0.45 + random-float 0.05 ;scale factor has to strictly be less than 0.5 (e < 1/2)
              ;a lower bound for estimated-baseline-unit-cost is cbeta > e * market-size; also, cbeta should be lower than the price-intercept (a - cbeta > 0)
              ;notice that beta-type firms DO NOT use any scale factor, but we need it here to obtain a lower bound for the random drawing
              let estimated-baseline-unit-cost  (estimated-scale-factor * market-size) + random-float (price-equation-intercept - estimated-scale-factor * market-size)
              let scenario-i-quantity (price-equation-intercept - estimated-baseline-unit-cost) / (2 * price-equation-slope)  ;q = (a-c_beta)/(2*b)
              set profit-new-variant (price-equation-intercept - price-equation-slope * scenario-i-quantity) * scenario-i-quantity - estimated-baseline-unit-cost * scenario-i-quantity ;profits = (a-b*q)*q - c_beta*q; note that the firm assumes the current (known) slope value.
             ]

             ;NOTE: In this model we are not taking into account demand redistribution when the firm considers expansion
             set inactive-related-profits sum profits-per-variant + profit-new-variant - niche-width-cost * block-distance niche-positions-old - K-cost
      ] ;end if length inactive-patch-candidates > 0

      ;computation of profits -- case (iii)
      ;----------------------------------------------------------------------------------------------------------------------------
      let active-selected -1 ;initialization; this variable picks up one of the active-patch-candidates
      let active-related-profits -1e300 ;initialization
      if length active-patch-candidates > 0 [
         set active-selected one-of active-patch-candidates
         let niche-positions-old niche-positions
         set niche-positions-old lput active-selected niche-positions
         let profit-new-variant 0
         let variant-id 0 ;initialization
         ask patches with [patch-id = active-selected] [set variant-id item 0 [who] of variants-here]

         let scale-factor-here [scale-factor] of variant variant-id
         let baseline-unit-cost-here [baseline-unit-cost] of variant variant-id

         ifelse firm-type = "alpha"
                [
                 let n-alpha-here ([n-alpha] of variant variant-id) + 1 ;we add this firm
                 let n-beta-here ([n-beta] of variant variant-id)
                 let Q-beta-here ([Q-beta] of variant variant-id)

                 ;Qalpha = nalpha*(a-cbeta)/(b*(nalpha+nbeta+1)-2e(nbeta+1))
                 let new-Q-alpha n-alpha-here * (price-equation-intercept - baseline-unit-cost-here)/(price-equation-slope * (n-alpha-here + n-beta-here + 1) - 2 * scale-factor-here * (n-beta-here + 1))
                 let scenario-iii-quantity new-Q-alpha / n-alpha-here

                 ;we compute profits = (a-b*Q)*q - (c_beta - e*q) * q
                 set profit-new-variant (price-equation-intercept - price-equation-slope * (new-Q-alpha + Q-beta-here)) * scenario-iii-quantity - (baseline-unit-cost-here - scale-factor-here * scenario-iii-quantity) * scenario-iii-quantity

                ]
                [;that is, if firm type is "beta"
                 let n-alpha-here ([n-alpha] of variant variant-id)
                 let n-beta-here [n-beta] of variant variant-id + 1 ;we add this firm
                 let Q-alpha-here ([Q-alpha] of variant variant-id)

                 ;Qbeta = (nbeta*((b-2e)/b) * (a-cbeta) / (b*(nalpha+nbeta+1)-2e(nbeta+1))
                 let new-Q-beta (n-beta-here * ((price-equation-slope - 2 * scale-factor-here) / price-equation-slope)) * (price-equation-intercept - baseline-unit-cost-here)/(price-equation-slope * (n-alpha-here + n-beta-here + 1) - 2 * scale-factor-here * (n-beta-here + 1))
                 let scenario-iii-quantity new-Q-beta / n-beta-here
                 ;we compute profits = (a-b*Q)*q - c_beta*q
                 set profit-new-variant (price-equation-intercept - price-equation-slope * (Q-alpha-here + new-Q-beta)) * scenario-iii-quantity - baseline-unit-cost-here * scenario-iii-quantity
                ]

                set active-related-profits sum profits-per-variant + profit-new-variant - niche-width-cost * block-distance niche-positions-old

      ] ;end if length active-patch-candidates > 0

      ;computation of profits -- case (iV)
      ;----------------------------------------------------------------------------------------------------------------------------
      let dropped-selected -1 ;initialization; this variable represents the niche position selected to be dropped
      let dropped-position-profits -1e300; initialization
      if length niche-positions > 1 [
         let selected-dropped-profit min profits-per-variant ;finds the least profitable product variant in niche
         let position-dropped-selected position selected-dropped-profit profits-per-variant ;finds the location in vector of the to-be-dropped position in profits-per-variant vector
         set dropped-selected item position-dropped-selected niche-positions ;finds the to-be-dropped position in niche-positions
         let niche-positions-old niche-positions
         set niche-positions-old remove dropped-selected niche-positions ;deletes dropped position from niche
         let profit-variants-without-dropped remove-item position-dropped-selected profits-per-variant ;computes profits selecting out dropped position from profits-per-variant

         ;notice that dropped positions remain opened!
         set dropped-position-profits sum profit-variants-without-dropped - niche-width-cost * block-distance niche-positions-old
      ]; end if length niche-positions > 1

      ;determine which is highest expected profit {(i), (ii), (iii), (iv)}
      ;----------------------------------------------------------------------------------------------------------------------------

      let profit-scenario-list (list last-transaction-profit inactive-related-profits active-related-profits dropped-position-profits)

      if max profit-scenario-list = inactive-related-profits [
         set niche-positions lput inactive-selected niche-positions
         set variants-to-create lput inactive-selected variants-to-create
         ifelse firm-type = "alpha" [
                 set variants-opened-up-by-alpha variants-opened-up-by-alpha + 1
                ]
                [;otherwise firm-type is beta
                 set variants-opened-up-by-beta variants-opened-up-by-beta + 1
                ]

         set quantity-per-variant lput 0 quantity-per-variant
         set unit-cost-per-variant lput 0 unit-cost-per-variant
         set profits-per-variant lput 0 profits-per-variant
         set overall-cumulative-profits (overall-cumulative-profits - k-cost) ;IMPORTANT: k-cost is discounted at this point if the firm decides to open up a new variant.
         ;Notice the k-cost is independently incurred in the case two (or more) firms decide to open the same variant
         ;(e.g. market assessments are carried out independently and have the same cost for every firm that attempts them, even if such assessments are made on the same target market).
      ]

      if max profit-scenario-list = active-related-profits [
         set niche-positions lput active-selected niche-positions
         set quantity-per-variant lput 0 quantity-per-variant
         set unit-cost-per-variant lput 0 unit-cost-per-variant
         set profits-per-variant lput 0 profits-per-variant
      ]

      if max profit-scenario-list = dropped-position-profits [
         let location-dropped-position position dropped-selected niche-positions
         set niche-positions remove dropped-selected niche-positions
         set quantity-per-variant remove-item location-dropped-position quantity-per-variant
         set unit-cost-per-variant remove-item location-dropped-position unit-cost-per-variant
         set profits-per-variant remove-item location-dropped-position profits-per-variant

      ]

  ] ;end of "ask firms" block

end

to update-variant-population
   set variants-to-create remove-duplicates variants-to-create
   foreach variants-to-create [ ?1 ->
           create-variants 1 [
                  set color red
                  set xcor item 0 [pxcor] of patches with [patch-id = ?1]
                  set ycor item 0 [pycor] of patches with [patch-id = ?1]
                  set scale-factor 0.45 + random-float 0.05 ;scale factor has to strictly be less than 0.5 (e < 1/2)
                  ;a lower bound for baseline-unit-cost is cbeta > e * market-size; also, cbeta should be lower than the price-intercept (a - cbeta > 0)
                  set baseline-unit-cost (scale-factor * market-size) + random-float (price-equation-intercept - scale-factor * market-size)
                  create-links-with variants-on neighbors4

           ]
   ]

end

to update-variant-size

  let total-sold-quantity (sum [q-alpha] of variants) + (sum [q-beta] of variants)
   ask variants [
       set size 1  + ticks * (q-alpha + q-beta) / total-sold-quantity ;sets variant size proportional to sold quantity / elapsed time
  ]
end

;=================================================================
;                          REPORTS
;=================================================================

to-report block-distance [niche-vector] ;this reporter takes the list of niche-positions (patch-id's) of a firm and computes the maximum Hamming (block) distance between any two of its niche positions
  let hamming-distance 0 ;initialization
  let niche-pos-list-a niche-vector
  let niche-pos-list-b niche-vector

  let counter1 0 ;initialization; counter of first while-loop
  let counter2 0 ;initialization; counter of second while-loop
  let x-pos-temp-1 0 ;initialization; x position first list (a)
  let y-pos-temp-1 0 ;initialization; y position first list (a)
  let x-pos-temp-2 0 ;initialization; x position second list (b)
  let y-pos-temp-2 0 ;initialization; y position second list (b)
  let distance-x 0 ;initialization; horizontal distance between x positions
  let distance-y 0 ;initialization; vertical distance between y positions
  let total-distance 0 ;initialization; distance-x + distance-y

  while [counter1 < length niche-pos-list-a] [
        ifelse (item counter1 niche-pos-list-a > max-pxcor * 100 + max-pycor) [
                show "one of the positions is not a patch"
                set counter1 length niche-pos-list-a
                set hamming-distance 0
               ];end ifelse first block

               [;begin ifelse second block
                set x-pos-temp-1 item 0 ([pxcor] of patches with [patch-id = (item counter1 niche-pos-list-a)])

                set y-pos-temp-1 item 0 ([pycor] of patches with [patch-id = (item counter1 niche-pos-list-a)])

                set counter2 (counter1 + 1)
                while [counter2 < length niche-pos-list-b] [
                       ifelse (item counter2 niche-pos-list-b > max-pxcor * 100 + max-pycor) [
                               show "one of the positions is not a patch"
                               set counter1 length niche-pos-list-a
                               set counter2 length niche-pos-list-b
                               set hamming-distance 0
                              ];end ifelse first sub-block

                              [;begin ifelse second sub-block
                               set x-pos-temp-2 item 0 ([pxcor] of patches with [patch-id = (item counter2 niche-pos-list-b)])
                               ;show x-pos-temp-2
                               set y-pos-temp-2 item 0 ([pycor] of patches with [patch-id = (item counter2 niche-pos-list-b)])
                               ;show y-pos-temp-2
                               set distance-x abs (x-pos-temp-1 - x-pos-temp-2)
                               ;show distance-x
                               set distance-y abs (y-pos-temp-1 - y-pos-temp-2)
                               ;show distance-y
                               set total-distance distance-x + distance-y
                               ;show total-distance
                               set hamming-distance max list hamming-distance total-distance
                              ];end ifelse second sub-block

                       set counter2 counter2 + 1
                       ] ;end while [counter2 < length niche-pos-list-b]

                ] ;end ifelse second block

        set counter1 counter1 + 1
       ] ;end loop while [counter1 < length niche-pos-list-a]

  report hamming-distance

end

to-report fraction-dimension
   let dim ln (count variants) / ln (max-pxcor + 1)
   report precision dim 2
end

to-report avg-last-transaction-profit-alpha ;average last transaction profit for alpha firms. Notice k-cost is not part of last transaction costs.
  let numerator sum ([last-transaction-profit] of firms with [firm-type = "alpha"])
  let denominator count firms with [firm-type = "alpha"]
  let average-value 0
  if (denominator > 0) [set average-value numerator / denominator]
  report precision average-value 2
end

to-report avg-last-transaction-profit-beta ;average last transaction profit for beta firms. Notice k-cost is not part of last transaction costs.
  let numerator sum ([last-transaction-profit] of firms with [firm-type = "beta"])
  let denominator count firms with [firm-type = "beta"]
  let average-value 0
  if (denominator > 0) [set average-value numerator / denominator]
  report precision average-value 2
end

to-report avg-last-transaction-cost-alpha ;average last transaction cost for alpha firms. Notice k-cost is not part of last transaction costs.
   ifelse (count firms with [firm-type = "alpha"] > 0)
       [report precision ((sum [last-transaction-cost] of firms with [firm-type = "alpha"]) / (count firms with [firm-type = "alpha"])) 2]
       [report 0]
end

to-report avg-last-transaction-cost-beta ;average last transaction cost for beta firms. Notice k-cost is not part of last transaction costs.
   ifelse (count firms with [firm-type = "beta"] > 0)
       [report precision ((sum [last-transaction-cost] of firms with [firm-type = "beta"]) / (count firms with [firm-type = "beta"])) 2]
       [report 0]
end

to-report avg-cumulative-profits-alpha ;average cumulative profits for alpha firms
   let numerator sum ([overall-cumulative-profits] of firms with [firm-type = "alpha"])
   let denominator count firms with [firm-type = "alpha"]
   let average-value 0
   if (denominator > 0) [set average-value numerator / denominator]
   report precision average-value 2
end

to-report avg-cumulative-profits-beta ;average cumulative profits for beta firms
   let numerator sum ([overall-cumulative-profits] of firms with [firm-type = "beta"])
   let denominator count firms with [firm-type = "beta"]
   let average-value 0
   if (denominator > 0) [set average-value numerator / denominator]
   report precision average-value 2
end

to-report avg-niche-size-alpha-firms ;average niche size for alpha firms
   ifelse (count firms with [firm-type = "alpha"] > 0)
       [report precision ((sum [length niche-positions] of firms with [firm-type = "alpha"]) / (count firms with [firm-type = "alpha"])) 2]
       [report 0]
end

to-report avg-niche-size-beta-firms ;average niche size for beta firms
   ifelse (count firms with [firm-type = "beta"] > 0)
       [report precision ((sum [length niche-positions] of firms with [firm-type = "beta"]) / (count firms with [firm-type = "beta"])) 2]
       [report 0]
end

to-report avg-quantity-alpha ;average quantity for alpha firms
   report precision ((sum [sum quantity-per-variant] of firms with [firm-type = "alpha"]) / (count firms with [firm-type = "alpha"])) 2
end


to-report avg-quantity-beta ;average quantity for beta firms
   report precision ((sum [sum quantity-per-variant] of firms with [firm-type = "beta"]) / (count firms with [firm-type = "beta"])) 2
end

to-report avg-cost-alpha ;average cost for alpha firms. Notice k-cost is not part of last transaction costs.
   ifelse (sum [sum quantity-per-variant] of firms with [firm-type = "alpha"]) > 0
       [report precision ((sum ([last-transaction-cost / sum (quantity-per-variant)] of firms with [firm-type = "alpha"])) / (count firms with [firm-type = "alpha"])) 2]
       [report 0]
end

to-report avg-cost-beta ;average cost for beta firms. Notice k-cost is not part of last transaction costs.
   ifelse (sum [sum quantity-per-variant] of firms with [firm-type = "beta"]) > 0
       [report precision ((sum ([last-transaction-cost / sum (quantity-per-variant)] of firms with [firm-type = "beta"])) / (count firms with [firm-type = "beta"])) 2]
       [report 0]
end

to-report number-of-new-variants
   ifelse ticks = 0 [report 0][report length variants-to-create]
end

to-report Herfindahl ;computes the Herfindahl-Hirschman index
  let total-quantity-per-firm []
  let all-firms sort [who] of firms ;all firm id's sorted in ascendent order
  foreach all-firms [[x] ->
    set total-quantity-per-firm lput (sum [quantity-per-variant] of firm x) total-quantity-per-firm
  ];end foreach
  let market-share-squared map [[x] -> (x / market-size) ^ 2 ] total-quantity-per-firm
  report sum market-share-squared
end
@#$#@#$#@
GRAPHICS-WINDOW
3
10
393
401
-1
-1
34.73
1
10
1
1
1
0
0
0
1
0
10
0
10
1
1
1
ticks
15.0

BUTTON
63
427
157
473
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
160
427
244
474
go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
249
427
340
474
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
581
11
842
44
total-number-of-firms
total-number-of-firms
5
75
10.0
1
1
(number of firms)
HORIZONTAL

SLIDER
581
55
846
88
market-size
market-size
1000
5000
5000.0
100
1
(number of consumers)
HORIZONTAL

SLIDER
460
10
574
43
initial-x-position
initial-x-position
0
10
5.0
1
1
NIL
HORIZONTAL

SLIDER
460
55
574
88
initial-y-position
initial-y-position
0
10
5.0
1
1
NIL
HORIZONTAL

SLIDER
850
11
1196
44
niche-width-cost
niche-width-cost
0
1500
575.0
1
1
NIL
HORIZONTAL

SLIDER
848
54
1197
87
K-cost
K-cost
0
25000
15625.0
1
1
(one-time cost of opening a variant)
HORIZONTAL

BUTTON
110
482
199
542
Highlight
if firm-to-highlight <= total-number-of-firms [\n   let chosen-color random-float 140\n   ask firm firm-to-highlight [\n       foreach niche-positions [ ?1 ->\n               ask patches with [patch-id = ?1] [\n                   ask variants-here [set color chosen-color]\n               ]\n       ]\n   ]\n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
204
483
303
543
firm-to-highlight
1.0
1
0
Number

PLOT
760
102
1075
269
Last transaction profit (excluding the "one time" k-cost)
Dimension
Average profits
0.0
2.0
0.0
10.0
true
true
"" ""
PENS
"alpha-type" 1.0 0 -2674135 true "plotxy fraction-dimension avg-last-transaction-profit-alpha" "plotxy fraction-dimension avg-last-transaction-profit-alpha"
"beta-type" 1.0 0 -13345367 true "plotxy fraction-dimension avg-last-transaction-profit-beta" "plotxy fraction-dimension avg-last-transaction-profit-beta"

PLOT
1089
103
1385
268
Fraction dimension
Time
Fraction dimension
0.0
10.0
0.0
2.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "plot fraction-dimension" "plot fraction-dimension"

PLOT
1089
278
1384
428
Cumulative number of decisions to create a variant 
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"alpha-type" 1.0 0 -2674135 true "plot variants-opened-up-by-alpha" "plot variants-opened-up-by-alpha"
"beta-type" 1.0 0 -13345367 true "plot variants-opened-up-by-beta" "plot variants-opened-up-by-beta"

PLOT
761
277
1074
427
Average cumulative profits
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"alpha-type" 1.0 0 -2674135 true "plot avg-cumulative-profits-alpha ;average cumulative profits for alpha firms" "plot avg-cumulative-profits-alpha ;average cumulative profits for alpha firms"
"beta-type" 1.0 0 -13345367 true "plot avg-cumulative-profits-beta ;average cumulative profits for beta firms" "plot avg-cumulative-profits-beta ;average cumulative profits for beta firms"

PLOT
763
431
1074
601
last iteration firm size
Time
Average firm size
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"alpha-type" 1.0 0 -2674135 true "plot avg-quantity-alpha" "plot avg-quantity-alpha"
"beta-type" 1.0 0 -13345367 true "plot avg-quantity-beta" "plot avg-quantity-beta"

PLOT
1089
436
1383
600
Average price
Time
Price
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"avg price" 1.0 0 -16777216 true "plot (sum [price] of variants) / (count variants)" "plot (sum [price] of variants) / (count variants)"
"max price" 1.0 0 -13840069 true "plot max [price] of variants" "plot max [price] of variants"
"min price" 1.0 0 -11221820 true "plot min [price] of variants" "plot min [price] of variants"

PLOT
461
104
756
270
New variants created
Time
number of new variants
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "plot number-of-new-variants" "plot number-of-new-variants"

PLOT
461
278
755
426
Last transaction costs per firm type
Time
Total cost / type
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"alpha-type" 1.0 0 -2674135 true "plot avg-last-transaction-cost-alpha" "plot avg-last-transaction-cost-alpha"
"beta-type" 1.0 0 -13345367 true "plot avg-last-transaction-cost-beta" "plot avg-last-transaction-cost-beta"

PLOT
462
432
756
603
Average niche size
Time
average niche size
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"alpha-type" 1.0 0 -2674135 true "plot avg-niche-size-alpha-firms ;average niche size for alpha firms" "plot avg-niche-size-alpha-firms ;average niche size for alpha firms"
"beta-type" 1.0 0 -13345367 true "plot avg-niche-size-beta-firms ;average niche size for beta firms" "plot avg-niche-size-beta-firms ;average niche size for beta firms"

PLOT
1089
611
1383
807
Distribution of quantities across variants
NIL
NIL
-5.0
50.0
0.0
10.0
true
true
"" ""
PENS
"Total" 1.0 1 -16777216 true "histogram [(Q-alpha + Q-beta)] of variants" "histogram [(Q-alpha + Q-beta)] of variants"
"alpha-type" 1.0 1 -2674135 true "histogram [(Q-alpha)] of variants" "histogram [(Q-alpha)] of variants"
"beta-type" 1.0 1 -13345367 true "histogram [(Q-beta)] of variants" "histogram [(Q-beta)] of variants"

PLOT
764
608
1074
807
Herfindahl - Hirchmann index
NIL
NIL
0.0
1.0
0.0
0.01
true
true
"" ""
PENS
"HH index" 1.0 0 -16777216 true "plot herfindahl" "plot herfindahl"

TEXTBOX
768
817
1031
887
HH < 0.01 --> highly competitive industry\n0.01 < HH < 0.15 --> unconcentrated industry\n0.15 < HH < 0.25 --> moderate concentration\nHH > 0.25 --> high concentration.
12
0.0
1

SLIDER
103
561
308
594
parameter-value-combination
parameter-value-combination
-1
19
2.0
1
1
NIL
HORIZONTAL

PLOT
460
609
755
807
Last transaction unit costs
Time
Avg unit cost
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"alpha-type" 1.0 0 -2674135 true "plot avg-cost-alpha" "plot avg-cost-alpha"
"beta-type" 1.0 0 -13345367 true "plot avg-cost-beta" "plot avg-cost-beta"

@#$#@#$#@
## CREDITS AND REFERENCES
Companion model of the paper:
"The coevolution of the firm and the product attribute space"
Coded by: Cesar Garcia-Diaz
This update: May 2020
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Experiment_coef_of_variation" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>Herfindahl</metric>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="-1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="K-cost">
      <value value="17500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="total-number-of-firms">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="niche-width-cost">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_0" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_1" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_2" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_3" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_4" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_5" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_6" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_7" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="7"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_8" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_9" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_10" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_11" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="11"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_12" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="12"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_13" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="13"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_14" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="14"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_15" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="15"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_16" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="16"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_17" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="17"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_18" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="18"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment_par_comb_19" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>fraction-dimension</metric>
    <metric>avg-last-transaction-profit-alpha</metric>
    <metric>avg-last-transaction-profit-beta</metric>
    <metric>avg-last-transaction-cost-alpha</metric>
    <metric>avg-last-transaction-cost-beta</metric>
    <metric>avg-cumulative-profits-alpha</metric>
    <metric>avg-cumulative-profits-beta</metric>
    <metric>avg-niche-size-alpha-firms</metric>
    <metric>avg-niche-size-beta-firms</metric>
    <metric>avg-quantity-alpha</metric>
    <metric>avg-quantity-beta</metric>
    <metric>number-of-new-variants</metric>
    <metric>Herfindahl</metric>
    <metric>variants-opened-up-by-alpha</metric>
    <metric>variants-opened-up-by-beta</metric>
    <enumeratedValueSet variable="parameter-value-combination">
      <value value="19"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
